@@ -8,42 +8,36 @@
 */
 
 #include "parleymainwindow.h"
-
-#include <config-parley.h>
+#include "dashboard/dashboard.h"
 #include "editor/editor.h"
-#include "statistics/statisticsmainwindow.h"
-#include "settings/parleyprefs.h"
+#include "parleyactions.h"
+#include "practice/configure/configurepracticedialog.h"
 #include "practice/guifrontend.h"
 #include "practice/practicesummarycomponent.h"
-#include "practice/configure/configurepracticedialog.h"
-
-#include "parleyactions.h"
-
 #include "prefs.h"
-#include "dashboard/dashboard.h"
-
+#include "settings/parleyprefs.h"
+#include "statistics/statisticsmainwindow.h"
 #include <KActionCollection>
-#include <KRecentFilesAction>
 #include <KMessageBox>
-#include <KTipDialog>
-#include <KXMLGUIFactory>
+#include <KNSWidgets/Action>
+#include <KRecentFilesAction>
 #include <KToolBar>
+#include <KXMLGUIFactory>
 #include <QMenuBar>
-
 #include <QTimer>
+#include <config-parley.h>
 
 using namespace Editor;
 
-ParleyMainWindow* ParleyMainWindow::s_instance = 0;
-ParleyMainWindow* ParleyMainWindow::instance()
+ParleyMainWindow *ParleyMainWindow::s_instance = nullptr;
+ParleyMainWindow *ParleyMainWindow::instance()
 {
     return s_instance;
 }
 
-ParleyMainWindow::ParleyMainWindow(const QUrl& filename)
-    : KXmlGuiWindow(0)
+ParleyMainWindow::ParleyMainWindow(const QUrl &filename)
+    : KXmlGuiWindow(nullptr)
     , m_currentComponent(NoComponent)
-    , m_currentComponentWindow(0)
     , m_sessionManager(this)
 {
     s_instance = this;
@@ -77,16 +71,13 @@ ParleyMainWindow::ParleyMainWindow(const QUrl& filename)
     setAutoSaveSettings();
 
     if (startWithDashboard) {
-	showDashboard();
+        showDashboard();
     } else {
         showEditor();
     }
 
     connect(this, &ParleyMainWindow::preferencesChanged, this, &ParleyMainWindow::slotApplyPreferences);
     menuBar()->show();
-
-    // finally show tip-of-day (if the user wants it)
-    //QTimer::singleShot( 0, this, SLOT(startupTipOfDay()) );
 }
 
 ParleyMainWindow::~ParleyMainWindow()
@@ -97,8 +88,7 @@ ParleyMainWindow::~ParleyMainWindow()
 
     // Prevent calling this slot with already deleted m_document as it is no longer needed anyway
     if (m_document->document()) {
-        disconnect(m_document->document().get(), &KEduVocDocument::destroyed,
-                this, &ParleyMainWindow::slotUpdateWindowCaption);
+        disconnect(m_document->document().get(), &KEduVocDocument::destroyed, this, &ParleyMainWindow::slotUpdateWindowCaption);
     }
     delete m_document;
 }
@@ -118,17 +108,15 @@ void ParleyMainWindow::removeRecentFile(const QUrl &url)
 void ParleyMainWindow::documentUpdated(const std::shared_ptr<KEduVocDocument> &doc)
 {
     if (doc) {
-        connect(doc.get(), &KEduVocDocument::docModified,
-                this, &ParleyMainWindow::slotUpdateWindowCaption);
-        connect(doc.get(), &KEduVocDocument::destroyed,
-                this, &ParleyMainWindow::slotUpdateWindowCaption);
+        connect(doc.get(), &KEduVocDocument::docModified, this, &ParleyMainWindow::slotUpdateWindowCaption);
+        connect(doc.get(), &KEduVocDocument::destroyed, this, &ParleyMainWindow::slotUpdateWindowCaption);
         slotUpdateWindowCaption();
     }
 }
 
 void ParleyMainWindow::updateRecentFilesModel()
 {
-    emit recentFilesChanged();
+    Q_EMIT recentFilesChanged();
 }
 
 void ParleyMainWindow::saveOptions()
@@ -141,8 +129,9 @@ void ParleyMainWindow::slotUpdateWindowCaption()
     QString title;
     bool modified = false;
     if (m_document->document()) {
-        title = i18nc("Title and a modified status indicator.  [*] is exact and will be shown only when document is modified"
-                      , "%1 [*]",m_document->document()->title());
+        title = i18nc("Title and a modified status indicator.  [*] is exact and will be shown only when document is modified",
+                      "%1 [*]",
+                      m_document->document()->title());
         modified = m_document->document()->isModified();
         if (title == i18n("Untitled")) {
             title = QStringLiteral("[*]");
@@ -153,7 +142,7 @@ void ParleyMainWindow::slotUpdateWindowCaption()
 
 void ParleyMainWindow::slotGeneralOptions()
 {
-    ParleyPrefs* dialog = new ParleyPrefs(m_document->document().get(), this, QStringLiteral("settings"),  Prefs::self());
+    ParleyPrefs *dialog = new ParleyPrefs(m_document->document().get(), this, QStringLiteral("settings"), Prefs::self());
     connect(dialog, &ParleyPrefs::settingsChanged, this, &ParleyMainWindow::preferencesChanged);
     dialog->show();
 }
@@ -174,21 +163,19 @@ void ParleyMainWindow::slotCloseDocument()
 
 void ParleyMainWindow::configurePractice()
 {
-    ConfigurePracticeDialog configurePracticeDialog(m_document->document().get(), this, QStringLiteral("practice settings"),  Prefs::self());
+    ConfigurePracticeDialog configurePracticeDialog(m_document->document().get(), this, QStringLiteral("practice settings"), Prefs::self());
     configurePracticeDialog.exec();
 }
 
 void ParleyMainWindow::startPractice()
 {
     if (Prefs::learningLanguage() == Prefs::knownLanguage()) {
-        KMessageBox::sorry(this,
-                           i18n("You cannot start to practice when the known language is the same as the language to learn."),
-                           i18n("Select languages"));
+        KMessageBox::sorry(this, i18n("You cannot start to practice when the known language is the same as the language to learn."), i18n("Select languages"));
         return;
     }
-    qDebug() <<"Starting Switch Practice";
+    qDebug() << "Starting Switch Practice";
     switchComponent(PracticeComponent);
-    qDebug() <<"Finished Switch Practice";
+    qDebug() << "Finished Switch Practice";
 }
 
 void ParleyMainWindow::practiceFinished()
@@ -210,16 +197,6 @@ QSize ParleyMainWindow::sizeHint() const
     return QSize(800, 600).expandedTo(KXmlGuiWindow::minimumSizeHint());
 }
 
-void ParleyMainWindow::tipOfDay()
-{
-    KTipDialog::showTip(this, QStringLiteral("parley/tips"), true);
-}
-
-void ParleyMainWindow::startupTipOfDay()
-{
-    KTipDialog::showTip(this, QStringLiteral("parley/tips"));
-}
-
 void ParleyMainWindow::slotFileNew()
 {
     m_document->slotFileNew();
@@ -230,11 +207,18 @@ void ParleyMainWindow::initActions()
 {
     ParleyActions::create(ParleyActions::FileNew, this, SLOT(slotFileNew()), actionCollection());
     ParleyActions::create(ParleyActions::FileOpen, m_document, SLOT(slotFileOpen()), actionCollection());
-    ParleyActions::createDownloadAction(m_document, SLOT(slotGHNS()), actionCollection());
+
+    KNSWidgets::Action *pAction = new KNSWidgets::Action(i18n("Download New Vocabularies..."), QStringLiteral("parley.knsrc"), actionCollection());
+    actionCollection()->addAction(QStringLiteral("file_ghns"), pAction);
+    QObject::connect(pAction, &KNSWidgets::Action::dialogFinished, m_document, &ParleyDocument::slotGHNS);
+
+    pAction->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_G));
+    actionCollection()->setDefaultShortcut(pAction, QKeySequence(Qt::CTRL | Qt::Key_G));
+    pAction->setToolTip(i18n("Downloads new vocabulary collections"));
+
     ParleyActions::create(ParleyActions::FileOpenDownloaded, m_document, SLOT(openGHNS()), actionCollection());
 
-    m_recentFilesAction = ParleyActions::createRecentFilesAction(
-        m_document, SLOT(slotFileOpenRecent(QUrl)), actionCollection());
+    m_recentFilesAction = ParleyActions::createRecentFilesAction(m_document, SLOT(slotFileOpenRecent(QUrl)), actionCollection());
     m_recentFilesAction->loadEntries(KSharedConfig::openConfig()->group("Recent Files"));
 
     ParleyActions::create(ParleyActions::FileSave, m_document, SLOT(save()), actionCollection());
@@ -248,8 +232,6 @@ void ParleyMainWindow::initActions()
     ParleyActions::create(ParleyActions::FileClose, this, SLOT(slotCloseDocument()), actionCollection());
     ParleyActions::create(ParleyActions::FileQuit, this, SLOT(close()), actionCollection());
     ParleyActions::create(ParleyActions::Preferences, this, SLOT(slotGeneralOptions()), actionCollection());
-
-    actionCollection()->addAction(KStandardAction::TipofDay,  QStringLiteral("help_tipofday"), this, SLOT(tipOfDay()));
 }
 
 void ParleyMainWindow::showDashboard()
@@ -280,8 +262,7 @@ void ParleyMainWindow::showPracticeSummary()
 void ParleyMainWindow::switchComponent(Component component)
 {
     if (component == PracticeComponent) {
-
-        StatisticsMainWindow *statisticsWidget = qobject_cast<StatisticsMainWindow*>(m_currentComponentWindow);
+        StatisticsMainWindow *statisticsWidget = qobject_cast<StatisticsMainWindow *>(m_currentComponentWindow);
         if (statisticsWidget) {
             statisticsWidget->syncConfig();
         }
@@ -306,7 +287,7 @@ void ParleyMainWindow::switchComponent(Component component)
         Dashboard *dashboard = new Dashboard(this);
         m_currentComponentWindow = dashboard;
         showDocumentActions(true, false);
-        //dashboard->updateRecentFilesModel();
+        // dashboard->updateRecentFilesModel();
         break;
     }
     case ConfigurePracticeComponent: {
@@ -328,14 +309,14 @@ void ParleyMainWindow::switchComponent(Component component)
         Practice::PracticeMainWindow *practiceWindow = new Practice::PracticeMainWindow(&m_sessionManager, this);
         connect(practiceWindow, &Practice::PracticeMainWindow::stopPractice, this, &ParleyMainWindow::showPracticeSummary);
         m_currentComponentWindow = practiceWindow;
-        qDebug() <<" Practice Slotted up";
+        qDebug() << " Practice Slotted up";
         showDocumentActions(false, false);
         practiceWindow->startPractice();
-        qDebug() <<" Practice Slotted up2";
+        qDebug() << " Practice Slotted up2";
         break;
     }
     case PracticeSummary: {
-        Practice::PracticeSummaryComponent* summary = new Practice::PracticeSummaryComponent(&m_sessionManager, this);
+        Practice::PracticeSummaryComponent *summary = new Practice::PracticeSummaryComponent(&m_sessionManager, this);
         m_currentComponentWindow = summary;
         showDocumentActions(true, true);
         break;
@@ -343,7 +324,7 @@ void ParleyMainWindow::switchComponent(Component component)
     default:
         break;
     }
-    //qDebug() << "new component" << m_currentComponentWindow;
+    // qDebug() << "new component" << m_currentComponentWindow;
 
     guiFactory()->addClient(m_currentComponentWindow);
     centralWidget()->layout()->addWidget(m_currentComponentWindow);
@@ -381,7 +362,6 @@ void ParleyMainWindow::showDocumentActions(bool open, bool edit)
     actionCollection()->action(QStringLiteral("file_new"))->setVisible(open);
     actionCollection()->action(QStringLiteral("file_open"))->setVisible(open);
     actionCollection()->action(QStringLiteral("file_open_recent"))->setVisible(open);
-    actionCollection()->action(QStringLiteral("file_ghns"))->setVisible(open);
     actionCollection()->action(QStringLiteral("file_open_downloaded"))->setVisible(open);
 
     actionCollection()->action(QStringLiteral("file_save"))->setVisible(edit);
@@ -394,9 +374,10 @@ void ParleyMainWindow::showDocumentActions(bool open, bool edit)
     actionCollection()->action(QStringLiteral("file_close"))->setVisible(edit);
 }
 
-void ParleyMainWindow::setVisibleToolbar(const QString& name)
+void ParleyMainWindow::setVisibleToolbar(const QString &name)
 {
-    Q_FOREACH(KToolBar * toolbar, toolBars()) {
+    const QList<KToolBar *> toolbars = toolBars();
+    for (KToolBar *toolbar : toolbars) {
         if (toolbar && toolbar->objectName() == name) {
             toolbar->show();
         } else if (toolbar) {
@@ -405,7 +386,7 @@ void ParleyMainWindow::setVisibleToolbar(const QString& name)
     }
 }
 
-ParleyDocument* ParleyMainWindow::parleyDocument()
+ParleyDocument *ParleyMainWindow::parleyDocument()
 {
     return m_document;
 }
